==> 2025-09-30-01-09-45-Create-Delight-Remake-Server-Create-Delight-Remake-v0.4.6.11.zip: kubejs/server_scripts/Ecliptic Seasons/tags.js <==
ServerEvents.tags("minecraft:item", e => {
    e.add("eclipticseasons:crops/average_moist", 
        "frycooks_delight:canola_seeds",
        "collectorsreap:pomegranate_seeds",
        "culturaldelights:corn_kernels",
        "culturaldelights:eggplant_seeds",
        "vintagedelight:cucumber_seeds",
        "festival_delicacies:chinese_cabbage_seeds",
        "festival_delicacies:garlic",
        "festival_delicacies:greenonion",
        "festival_delicacies:eggplant_seeds",
        "festival_delicacies:fennel_seeds",
        "createdelight:artemisia_argyi_seed",
        "createdelight:adzuki_beans_seed",
        "fruitsdelight:pear_leaves",
        "fruitsdelight:pear_sapling",
        "fruitsdelight:hawberry_leaves",
        "fruitsdelight:hawberry_sapling",
        "fruitsdelight:lychee_leaves",
        "fruitsdelight:lychee_sapling",
        "fruitsdelight:orange_leaves",
        "fruitsdelight:orange_sapling",
        "fruitsdelight:apple_leaves",
        "fruitsdelight:apple_sapling",
        "fruitsdelight:kiwi_leaves",
        "fruitsdelight:kiwi_sapling",
        "fruitsdelight:cranberry",
        "neapolitan:mint_sprout",
        "vinery:red_grape_seeds",
        "vinery:white_grape_seeds",
        "vinery:dark_cherry_leaves",
        "farmersdelight:onion",
        "farmersdelight:cabbage_seeds",
        "festival_delicacies:garlic_chive_seeds",
        "fruitsdelight:fig_leaves",
        "fruitsdelight:fig_sapling",
        "fruitsdelight:blueberry_bush",
        "vintagedelight:peanut"
    )
    e.add("eclipticseasons:crops/moist_humid", 
        "collectorsreap:lime_seeds",
        "fruitsdelight:persimmon_leaves",
        "fruitsdelight:persimmon_sapling",
        "fruitsdelight:peach_leaves",
        "fruitsdelight:peach_sapling",
        "fruitsdelight:mangosteen_leaves",
        "fruitsdelight:mangosteen_sapling",
        "fruitsdelight:bayberry_leaves",
        "fruitsdelight:bayberry_sapling",
        "fruitsdelight:lemon_seeds",
        "fruitsdelight:lemon_tree",
        "neapolitan:strawberry_pips",
        "fruitsdelight:durian_leaves",
        "fruitsdelight:durian_sapling",
        "neapolitan:banana_frond",
        "oceanic_delight:sea_grape",
        "vinery:dark_cherry_sapling",
        "createcafe:coffee_beans",
        "miners_delight:cave_carrot"
    )    
    e.add("eclipticseasons:crops/average_humid",
        "farmersrespite:tea_seeds"
    )
    e.add("eclipticseasons:crops/dry_moist",
        "vinery:taiga_grape_seeds_red",
        "vinery:taiga_grape_seeds_white",
        "neapolitan:vanilla_pods",
        "vintagedelight:ghost_pepper_seeds",
        "vinery:savanna_grape_seeds_red",
        "vinery:savanna_grape_seeds_white",
        "createcafe:cassava_seeds",
        "fruitsdelight:hamimelon_seeds",
        "vintagedelight:oat_seeds",
        "trailandtales_delight:lantern_fruit_seeds",
        "youkaishomecoming:soybean",
        "kinetic_pixel:graycottonseed"
    )
    e.add("eclipticseasons:crops/dry_humid",
        "fruitsdelight:mango_leaves",
        "fruitsdelight:mango_sapling",
        "vinery:jungle_grape_seeds_white",
        "vinery:jungle_grape_seeds_red",
        "youkaishomecoming:mandrake_root"
    )
})

==> 2025-12-07-22-57-44-Create-Delight-Remake-Server-Create-Delight-Remake-v0.4.7.5.zip: kubejs/server_scripts/Ecliptic Seasons/tags.js <==
ServerEvents.tags("minecraft:item", e => {
    e.add("eclipticseasons:crops/average_moist", 
        "frycooks_delight:canola_seeds",
        "collectorsreap:pomegranate_seeds",
        "culturaldelights:corn_kernels",
        "culturaldelights:eggplant_seeds",
        "vintagedelight:cucumber_seeds",
        "festival_delicacies:chinese_cabbage_seeds",
        "festival_delicacies:garlic",
        "festival_delicacies:greenonion",
        "festival_delicacies:eggplant_seeds",
        "festival_delicacies:fennel_seeds",
        "createdelight:artemisia_argyi_seed",
        "createdelight:adzuki_beans_seed",
        "fruitsdelight:pear_leaves",
        "fruitsdelight:pear_sapling",
        "fruitsdelight:hawberry_leaves",
        "fruitsdelight:hawberry_sapling",
        "fruitsdelight:lychee_leaves",
        "fruitsdelight:lychee_sapling",
        "fruitsdelight:orange_leaves",
        "fruitsdelight:orange_sapling",
        "fruitsdelight:apple_leaves",
        "fruitsdelight:apple_sapling",
        "fruitsdelight:kiwi_leaves",
        "fruitsdelight:kiwi_sapling",
        "fruitsdelight:cranberry",
        "neapolitan:mint_sprout",
        "vinery:red_grape_seeds",
        "vinery:white_grape_seeds",
        "vinery:dark_cherry_leaves",
        "farmersdelight:onion",
        "farmersdelight:cabbage_seeds",
        "festival_delicacies:garlic_chive_seeds",
        "fruitsdelight:fig_leaves",
        "fruitsdelight:fig_sapling",
        "fruitsdelight:blueberry_bush",
        "vintagedelight:peanut"
    )
    e.add("eclipticseasons:crops/moist_humid", 
        "collectorsreap:lime_seeds",
        "fruitsdelight:persimmon_leaves",
        "fruitsdelight:persimmon_sapling",
        "fruitsdelight:peach_leaves",
        "fruitsdelight:peach_sapling",
        "fruitsdelight:mangosteen_leaves",
        "fruitsdelight:mangosteen_sapling",
        "fruitsdelight:bayberry_leaves",
        "fruitsdelight:bayberry_sapling",
        "fruitsdelight:lemon_seeds",
        "fruitsdelight:lemon_tree",
        "neapolitan:strawberry_pips",
        "fruitsdelight:durian_leaves",
        "fruitsdelight:durian_sapling",
        "neapolitan:banana_frond",
        "oceanic_delight:sea_grape",
        "vinery:dark_cherry_sapling",
        "createcafe:coffee_beans",
        "miners_delight:cave_carrot",
        'alexscaves:fiddlehead'
    )    
    e.add("eclipticseasons:crops/average_humid",
        "farmersrespite:tea_seeds"
    )
    e.add("eclipticseasons:crops/dry_moist",
        "vinery:taiga_grape_seeds_red",
        "vinery:taiga_grape_seeds_white",
        "neapolitan:vanilla_pods",
        "vintagedelight:ghost_pepper_seeds",
        "vinery:savanna_grape_seeds_red",
        "vinery:savanna_grape_seeds_white",
        "createcafe:cassava_seeds",
        "fruitsdelight:hamimelon_seeds",
        "vintagedelight:oat_seeds",
        "trailandtales_delight:lantern_fruit_seeds",
        "youkaishomecoming:soybean",
        "kinetic_pixel:graycottonseed"
    )
    e.add("eclipticseasons:crops/dry_humid",
        "fruitsdelight:mango_leaves",
        "fruitsdelight:mango_sapling",
        "vinery:jungle_grape_seeds_white",
        "vinery:jungle_grape_seeds_red",
        "youkaishomecoming:mandrake_root"
    )
    e.add("eclipticseasons:crops/arid_average",
        "minecraft:crimson_fungus",
        "minecraft:warped_fungus",
        "mynethersdelight:crimson_fungus_colony",
        "mynethersdelight:warped_fungus_colony"
    )
})
